@@ -1,15 +1,23 @@
 package Git::Wrapper::File::RawModification;
 # ABSTRACT: Modification of a file in a commit
-$Git::Wrapper::File::RawModification::VERSION = '0.045';
+$Git::Wrapper::File::RawModification::VERSION = '0.046';
 use 5.006;
 use strict;
 use warnings;
 
 sub new {
   my ($class, $filename, $type, $perms_from, $perms_to, $blob_from, $blob_to) = @_;
+
+  my $score;
+  if ( defined $type && $type =~ s{^(.)([0-9]+)$}{$1} ) {
+    $score = $2;
+    (undef, $filename) = split(qr{\s+}, $filename, 2 );
+  }
+
   return bless {
     filename   => $filename,
     type       => $type,
+    score      => $score,
     perms_from => $perms_from,
     perms_to   => $perms_to,
     blob_from  => $blob_from,
@@ -19,6 +27,7 @@ sub new {
 
 sub filename   { shift->{filename} }
 sub type       { shift->{type} }
+sub score      { shift->{score} }
 
 sub perms_from { shift->{perms_from} }
 sub perms_to   { shift->{perms_to} }
@@ -40,7 +49,7 @@ Git::Wrapper::File::RawModification - Modification of a file in a commit
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 METHODS
 
@@ -52,6 +61,8 @@ Constructor
 
 =head2 type
 
+=head2 score
+
 =head2 perms_from
 
 =head2 perms_to
